@@ -16,8 +16,10 @@ as.famset <- function(m, as.letters = TRUE) {
   if (sum(!(m == 0 | m == 1))) {
     stop(sprintf("%s must be a binary matrix.", dQuote("m")))
   }
-  if (as.letters) {
-    names <- make.unique(letters[0:(ncol(m)-1) %% 26 + 1])
+  if (!is.null(colnames(m))) {
+    names <- colnames(m)
+  } else if (as.letters) {
+    names <- make.unique(letters[(0L:(ncol(m)-1)) %% 26 + 1])
   } else {
     names <- as.integer(1L:ncol(m))
   }
