@@ -8,6 +8,7 @@
 ###
 ### 2008-05-29: created
 ### 2018-04-13: completely rewritten
+### 2019-04-07: Replacing nested for-loops with lapply commands
 ###
 
 as.relation.kstructure <- function(x,...) {
@@ -23,13 +24,14 @@ as.relation.kstructure <- function(x,...) {
    colnames(relmat) <- dom
    rownames(relmat) <- dom
    strmat <- as.binaryMatrix(x)
-   for (i in 1:dim(strmat)[2]) {
-     for (j in 1:dim(strmat)[2]) {
+   lapply(as.list(1:dim(strmat)[2]), function(i) {
+     lapply(as.list(1:dim(strmat)[2]), function(j) {
        if (all(strmat[,i] <= strmat[,j])) {
-         relmat[j,i] <- 1
+         relmat[j,i] <<- 1
        }
-     }
-   }
+     })
+   })
+   storage.mode(relmat) <- "integer"
    rel <- as.relation(relmat)
    rel
 }
