@@ -25,11 +25,13 @@ closure.kbase <- function(x, operation=c("union", "intersection"), ...) {
       colnames(relmat) <- dom
       y <- as.set(apply(relmat,1,function(z)as.set(names(which(z)))))      
       y <- set_union(y, set(set(), dom))
-
-   } else
+   } else 
       NextMethod()
 
-   class(clos) <- c("kstructure", "set", "gset", "cset")
+   if (operation == "union")
+      class(clos) <- c("kspace", "kstructure", "kfamset", "set", "gset", "cset")
+   else
+      class(clos) <- c("kstructure", "kfamset", "set", "gset", "cset")
       
    ### return closure
    clos
